---
name: Feature request
about: Suggest a new algorithm, enhancement to an existing algorithm, etc.
title: ''
labels: 'enhancement'
assignees: ''

---

<!--
Thanks for suggesting an improvement to groupyr.
-->

#### Describe the workflow you want to enable

#### Describe your proposed solution

#### Describe alternatives you've considered, if relevant

#### Additional context
